@@ -4,7 +4,7 @@
 #define FEED_H
 
 #include "core/message.h"
-#include "core/messagefilter.h"
+#include "filtering/messagefilter.h"
 #include "services/abstract/feedrtlbehavior.h"
 #include "services/abstract/rootitem.h"
 
@@ -50,7 +50,8 @@ class RSSGUARD_DLLSPEC Feed : public RootItem {
       AuthError = 3,
       ParsingError = 4,
       OtherError = 5,
-      Fetching = 6
+      Fetching = 6,
+      SqlError = 7
     };
 
     Q_ENUM(Status)
@@ -59,11 +60,10 @@ class RSSGUARD_DLLSPEC Feed : public RootItem {
     explicit Feed(const Feed& other);
     explicit Feed(const QString& title, const QString& custom_id, const QIcon& icon, RootItem* parent = nullptr);
 
-    virtual QList<Message> undeletedMessages() const;
     virtual QString additionalTooltip() const;
-    virtual Qt::ItemFlags additionalFlags() const;
-    virtual bool markAsReadUnread(ReadStatus status);
-    virtual bool cleanMessages(bool clean_read_only);
+    virtual Qt::ItemFlags additionalFlags(int column) const;
+    virtual void markAsReadUnread(ReadStatus status);
+    virtual void cleanMessages(bool clean_read_only);
     virtual int countOfAllMessages() const;
     virtual int countOfUnreadMessages() const;
     virtual QVariantHash customDatabaseData() const;
@@ -88,9 +88,6 @@ class RSSGUARD_DLLSPEC Feed : public RootItem {
     QString source() const;
     void setSource(const QString& source);
 
-    bool openArticlesDirectly() const;
-    void setOpenArticlesDirectly(bool opn);
-
     bool isSwitchedOff() const;
     void setIsSwitchedOff(bool switched_off);
 
@@ -108,14 +105,16 @@ class RSSGUARD_DLLSPEC Feed : public RootItem {
     RtlBehavior rtlBehavior() const;
     void setRtlBehavior(RtlBehavior rtl);
 
-    bool removeUnwantedArticles(QSqlDatabase& db);
+    bool removeUnwantedArticles();
 
     ArticleIgnoreLimit& articleIgnoreLimit();
     const ArticleIgnoreLimit& articleIgnoreLimit() const;
     void setArticleIgnoreLimit(const ArticleIgnoreLimit& ignore_limit);
 
+    static bool isErrorStatus(Feed::Status status);
+
   public slots:
-    virtual void updateCounts(bool including_total_count);
+    virtual void updateCounts();
 
   protected:
     QString getAutoUpdateStatusDescription() const;
@@ -130,7 +129,6 @@ class RSSGUARD_DLLSPEC Feed : public RootItem {
     QDateTime m_lastUpdated;
     bool m_isSwitchedOff;
     bool m_isQuiet;
-    bool m_openArticlesDirectly;
     RtlBehavior m_rtlBehavior;
 
     // NOTE: These are used to filter out older articles
